@@ -4,7 +4,9 @@
 #include "RcppArmadillo.h"
 #include "partitionfuns.h"
 
-void update_dist_mat(arma::mat& dist_mat, const arma::mat& rankings, const arma::mat& rho_old, const std::string& metric);
+void update_dist_mat(arma::mat& dist_mat, const arma::mat& rankings,
+                     const arma::mat& rho_old, const std::string& metric,
+                     const arma::vec& obs_freq);
 
 arma::uvec update_cluster_labels(
     const arma::mat& dist_mat,
